.. include:: ../README.rst

Contents
########

.. toctree::
   :maxdepth: 2

   vdoc
   getting_started
   configuration
   plugins
   development


License Compliance Information
##############################

.. toctree::
   :maxdepth: 1

   license_compliance
